#!/usr/bin/env node
'use strict'

var _fs = _interopRequireDefault(require('fs'))

var _path = _interopRequireDefault(require('path'))

var _chalk = _interopRequireDefault(require('chalk'))

var _yargs = _interopRequireDefault(require('yargs'))

var _child_process = _interopRequireDefault(require('child_process'))

var _templateUtils = require('@inst-cli/template-utils')

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {default: obj}
}

_yargs.default.scriptName('build-react-app')

_yargs.default.command(
  'now [-p|--prod] [-rm|--remove]',
  'Deploys the app to Now',
  y => {
    y.option('prod', {
      alias: 'p',
      describe: `Deploys in the production environment.`,
      type: 'boolean',
    })
    y.option('remove', {
      alias: 'rm',
      describe: `Deletes your deployment in the current environment`,
      type: 'boolean',
    })
  }
)

_yargs.default.command(
  'aws  [-s|--stage stage] [-rm|--remove]',
  'Deploys the app to AWS',
  y => {
    y.option('stage', {
      alias: 's',
      type: 'string',
      describe: `The stage to deploy to. Defaults to 'staging'.`,
    })
    y.option('remove', {
      alias: 'rm',
      describe: `Deletes your deployment in the current stage and environment`,
      type: 'boolean',
    })
  }
)

_yargs.default.command(
  'github [-rm|--remove]',
  'Deploys the app to GitHub Pages. GitHub Pages builds only have a production option.',
  y => {
    y.option('remove', {
      alias: 'rm',
      describe: `Deletes your deployment`,
      type: 'boolean',
    })
  }
)

const args = _yargs.default.argv
const pkg = (0, _templateUtils.getPkgJson)((0, _templateUtils.pwd)())
const crossEnv = (0, _templateUtils.findBin)('cross-env')
let cmd, stage

switch (args._[0]) {
  case 'now':
    if (args.remove)
      (0, _templateUtils.log)(
        `Tearing down ${_chalk.default.bold(
          pkg.name
        )} from ${_chalk.default.bold('Now')}`
      )
    else
      (0, _templateUtils.log)(
        `Deploying ${_chalk.default.bold(pkg.name)} to ${_chalk.default.bold(
          'Now'
        )}`
      )
    let nowJson = JSON.parse(
      _fs.default.readFileSync(
        _path.default.join(_path.default.dirname(pkg.__path), 'now.json'),
        {
          encoding: 'utf8',
        }
      )
    )
    cmd = `
      now \
        ${args.remove ? `rm ${nowJson.name}` : ''} \\
        ${args.prod ? '--prod' : ''}
    `
    break

  case 'github':
    if (args.remove)
      (0, _templateUtils.log)(
        `Tearing down ${_chalk.default.bold(
          pkg.name
        )} from ${_chalk.default.bold('GitHub Pages')}`
      )
    else
      (0, _templateUtils.log)(
        `Deploying ${_chalk.default.bold(pkg.name)} to ${_chalk.default.bold(
          'GitHub Pages'
        )}`
      )
    cmd = `${crossEnv} NODE_ENV=production`
    break

  case 'aws':
    if (args.remove)
      (0, _templateUtils.log)(
        `Tearing down ${_chalk.default.bold(
          pkg.name
        )} from ${_chalk.default.bold('AWS')}`
      )
    else
      (0, _templateUtils.log)(
        `Deploying ${_chalk.default.bold(pkg.name)} to ${_chalk.default.bold(
          'AWS'
        )}`
      )
    stage = typeof args.stage === 'string' ? args.stage : 'staging'
    stage = args.prod ? 'production' : stage
    cmd = `
      ${crossEnv} \
        NODE_ENV=production \
        STAGE=${stage} \
      npx serverless \
        ${args.remove ? 'remove' : 'deploy'} \\
        --stage ${stage} 
    `
    break

  default:
    ;(0, _templateUtils.error)(
      `Unrecognized deployment strategy: "${args._[0]}"`
    )
    process.exit(1)
}

const main = cmd => {
  const proc = _child_process.default.spawn(`${cmd.trim()}`, [], {
    stdio: 'inherit',
    shell: true,
  })

  return new Promise(resolve => proc.on('close', resolve))
}

main(cmd).then(() => process.exit(0))
